==> haskell-hsyaml-0.1.1.2-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsYAML
version: 0.1.1.2
id: HsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
key: HsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
license: GPL-2.0-only
copyright: 2015-2018 Herbert Valerio Riedel
           , 2007-2008 Oren Ben-Kiki
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/HsYAML
synopsis: Pure Haskell YAML 1.2 parser
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) parser implementation for Haskell.
    .
    Features of @HsYAML@ include:
    .
    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas).
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").
    .
category: Text
abi: a3326d437f053c27102e27b0ddefdb18
exposed: True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Token
hidden-modules: Data.YAML.Loader Data.YAML.Schema
                Data.YAML.Token.Encoding Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/HsYAML-0.1.1.2
hs-libraries: HSHsYAML-0.1.1.2-L3uIkgbsNak4k7y8EuGnVL
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD containers-0.5.11.0
    text-1.2.3.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             dlist-0.8.0.4-CrGJIvQnsM82JxkEwejrYD=f79b3ead594e04b4f22b6b2afc0a8656
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
haddock-interfaces: /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html: /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hsyaml-0.1.1.2-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hsyaml.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: HsYAML
version: 0.1.1.2
id: HsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
key: HsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
license: GPL-2.0-only
copyright: 2015-2018 Herbert Valerio Riedel
           , 2007-2008 Oren Ben-Kiki
maintainer: hvr@gnu.org
author: Herbert Valerio Riedel
homepage: https://github.com/hvr/HsYAML
synopsis: Pure Haskell YAML 1.2 parser
description:
    @HsYAML@ is a [YAML 1.2](http://yaml.org/spec/1.2/spec.html) parser implementation for Haskell.
    .
    Features of @HsYAML@ include:
    .
    * Pure Haskell implementation with small dependency footprint and emphasis on strict compliance with the [YAML 1.2 specification](http://yaml.org/spec/1.2/spec.html).
    * Direct decoding to native Haskell types via (@aeson@-inspired) typeclass-based API (see "Data.YAML").
    * Support for constructing custom YAML node graph representation (including support for cyclic YAML data structures).
    * Support for the standard (untyped) /Failsafe/, (strict) /JSON/, and (flexible) /Core/ \"schemas\" providing implicit typing rules as defined in the YAML 1.2 specification (including support for user-defined custom schemas).
    * Event-based API resembling LibYAML'\''s Event-based API (see "Data.YAML.Event").
    * Low-level API access to lexical token-based scanner (see "Data.YAML.Token").
    .
category: Text
abi: b2aeac0c0d87c97a5a6150b563d23324
exposed: True
exposed-modules:
    Data.YAML Data.YAML.Event Data.YAML.Token
hidden-modules: Data.YAML.Loader Data.YAML.Schema
                Data.YAML.Token.Encoding Util
import-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/HsYAML-0.1.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/HsYAML-0.1.1.2
hs-libraries: HSHsYAML-0.1.1.2-2zpifZwzGa8Kz9Q1vMaSOI
depends:
    base-4.11.1.0 bytestring-0.10.8.2
    dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6 containers-0.5.11.0
    text-1.2.3.0 mtl-2.2.2 parsec-3.1.13.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             dlist-0.8.0.5-6LWFCfMSEKNIqqazR8mrr6=f0c6d817a8f4177a2d0e3837521bb503
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
haddock-interfaces: /usr/share/doc/haskell-hsyaml/html/HsYAML.haddock
haddock-html: /usr/share/doc/haskell-hsyaml/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
